descendant.pere: first and last indexes of each sire progeny
Description
The function defines, for each sire, the first and last indexes of its progeny.
It can be viewed as an internal function.
The user does not have to call it by himself.
Usage
descendant.pere(genea)
Arguments
genea
numeric matrix (number of individuals x 2)
which contains the progeny index and its father index.
Value
The returned value is a numeric matrix (number of sires x 2) which gives for each sire, the first and last indexes of its progeny.
Details
Progeny data are prealably ordered by family
References
publication to be submitted: C. Cierco-Ayrolles, S. Dejean, A. Legarra, H. Gilbert,
T. Druet, F. Ytournel, D. Estivals, N. Oumouhou and B. Mangin.
Combining linkage analysis and linkage disequilibrium for QTL fine mapping in animal pedigrees.