Learn R Programming

HAPim (version 1.3)

haldanem1: recombination rate

Description

The function calculates recombination rates using Haldane distance. It can be viewed as an internal function. The user does not have to call it by himself.

Usage

haldanem1(distance)

Arguments

distance
vector of distances in Morgan.

Value

the returned value is a vector of recombination rates.

References

Haldane, J.B.S. J. Genet. (1919), 8:299-309.

publication to be submitted: C. Cierco-Ayrolles, S. Dejean, A. Legarra, H. Gilbert, T. Druet, F. Ytournel, D. Estivals, N. Oumouhou and B. Mangin. Combining linkage analysis and linkage disequilibrium for QTL fine mapping in animal pedigrees.