Learn R Programming

HAPim (version 1.3)

haplomax.HS.add: HaploMax method in half-sib family design

Description

The function computes an analysis of variance with a sire effect and a dose haplotype effect.

Usage

haplomax.HS.add(hap.chrom1.pere, hap.chrom2.pere, hap.trans.pere,
hap.trans.mere, perf, CD, genea, map, marq.hap)

Arguments

hap.chrom1.pere
character matrix (number of sires x number of markers) which gives the haplotype of the first chromosome for each sire.
hap.chrom2.pere
character matrix (number of sires x number of markers) which gives the haplotype of the second chromosome for each sire.
hap.trans.pere
numeric matrix (number of individuals x number of markers) which provides, for each individual, the haplotype transmitted by its father.
hap.trans.mere
numeric matrix (number of individuals x number of markers) which provides, for each individual, the haplotype transmitted by its mother.
perf
numeric vector of length=number of individuals which contains the performances of individuals.
CD
numeric vector of length=number of individuals which contains the CD of individuals. var(perf$_i$)=error variance/CD$^2_i$
genea
numeric matrix (number of individuals x 2) which contains the progeny index and its father index.
map
numeric vector of length=(number of markers-1) which contains the distance in Morgan between two consecutive markers on the chromosome.
marq.hap
number of markers of the mutated haplotype.

Value

The returned value is a data frame which contains 5 columns:-Test positions-Value of Fisher test-Mutated (i.e. associated to Q allele) haplotype-Estimate of the error variance-Estimate of the Q allele effect

Details

Progeny information have to be ranged in the same order in genea, hap.trans.pere, hap.trans.mere, perf and CD.

Sire information have to be ranged in the same order in unique(genea[,2]), hap.chrom1.pere and hap.chrom2.pere.

All distances are assumed to be Haldame's distance in Morgan.

Test positions are located on the middles of marq.hap marker sliding windows.

References

publication to be submitted: C. Cierco-Ayrolles, S. Dejean, A. Legarra, H. Gilbert, T. Druet, F. Ytournel, D. Estivals, N. Oumouhou and B. Mangin. Combining linkage analysis and linkage disequilibrium for QTL fine mapping in animal pedigrees.

Examples

Run this code

data(data.test)
map=data.test[[1]]
hap.trans.mere=data.test[[2]]
hap.trans.pere=data.test[[3]]
hap.chrom1.pere=data.test[[4]]
hap.chrom2.pere=data.test[[5]]
perf=data.test[[6]]
CD=data.test[[7]]
genea=data.test[[9]]

# In this example, marker positions are : 0, 0.010, 0.020, 0.030, 0.040, 0.050, 0.060,
# 0.070, 0.080, 0.090. 
# we use a 2 markers-associated haplotype

marq.hap=2

haplomax.HS=haplomax.HS.add(hap.chrom1.pere,hap.chrom2.pere,hap.trans.pere,hap.trans.mere,

perf,CD,genea,map,marq.hap)

haplomax.HS

Run the code above in your browser using DataLab