vrais.LD.add: log likelihood of HAPIimLD method under H1
Description
The function calculates the value of log likelihood of HAPimLD method under alternative hypothesis H1.
It can be viewed as an internal function.
The user does not have to call it by himself.
Usage
vrais.LD.add(mu, alpha.Q, s, CD, perf, DL.d)
Arguments
mu
parameter of the mean performances.
alpha.Q
parameter of QTL effect.
s
parameter of the error variance.
CD
numeric vector of length=number of individuals which contains the CD of individuals. var(perf$_i$)=s/CD$^2_i$
perf
numeric vector of length=number of individuals which contains the performances of individuals.
DL.d
results provided by proba.DL.diplotype() function, numeric matrix (number of individuals x 4) containing probabilities due to linkage disequilibrium for a diplotype.
Value
The returned value is the value of log likelihood of HAPimLD method under alternative hypothesis H1.
References
publication to be submitted: C. Cierco-Ayrolles, S. Dejean, A. Legarra, H. Gilbert,
T. Druet, F. Ytournel, D. Estivals, N. Oumouhou and B. Mangin.
Combining linkage analysis and linkage disequilibrium for QTL fine mapping in animal pedigrees.