Usage
vrais.LDL.add(moyenne.pere, alpha.Q, s, CD, perf, PLA, DL.m,
DL.chrom1,
DL.chrom2, desc.pere, mean.gene)
Arguments
moyenne.pere
results provided by moyenne.pere() function, mean of half-sib family performances.
alpha.Q
parameter of QTL effect.
s
parameter of the error variance.
CD
numeric vector of length=number of individuals which contains the CD of individuals. var(perf$_i$)=s/CD$^2_i$
perf
numeric vector of length=number of individuals which contains the performances of individuals.
PLA
numeric vector (number of individuals)
which contains transmission probabilities at a single test position.
DL.m
results provided by proba.DL() function, numeric vector of length=number of individuals
which contains probabilities due to linkage disequilibrium on dam.
DL.chrom1
results provided by proba.DL() function, numeric vector of length=number of individuals
which contains probabilities due to linkage disequilibrium on the first chromosome of sire.
DL.chrom2
results provided by proba.DL() function, numeric vector of length=number of individuals
which contains probabilities due to linkage disequilibrium on the second chromosome of sire.
desc.pere
results provided by descendant.pere() function, numeric matrix (number of sires x 2)
which gives for each sire, the first and last indexes of its progeny.
mean.gene
parameter of the performance mean.