Usage
vrais.LDL.add.pere(moyenne.pere, alpha.Q, s, CD, perf, PLA, LD.m, LD.chrom1,
LD.chrom2, mean.gene)
Arguments
moyenne.pere
results provided by moyenne.pere() function, mean of half-sib family performances.
alpha.Q
parameter of QTL effect.
s
parameter of the error variance.
CD
numeric vector of length=number of individuals which contains the CD of individuals. var(perf$_i$)=s/CD$^2_i$
perf
numeric vector of length=number of individuals which contains the performances of individuals.
PLA
numeric vector of length=number of individuals
which contains transmission probabilities at a single test position
LD.m
results provided by proba.DL() function, numeric vector of length=number of individuals
which contains probabilities due to linkage disequilibrium on dam.
LD.chrom1
results provided by proba.DL() function, numeric vector of length=number of individuals
which contains probabilities due to linkage disequilibrium on the first chromosome of sire.
LD.chrom2
results provided by proba.DL() function, numeric vector of length=number of individuals
which contains probabilities due to linkage disequilibrium on the second chromosome of sire.
mean.gene
parameter of performance mean.